@@ -158,7 +158,7 @@ enum { RIGHT, LEFT, TOP, BOTTOM, NOTHING };
 enum { METERS, KILOMETERS, MILES, SEA_MILES };
 enum { METERS_S, KILOMETERS_H, MILES_H, BEAUFORT_SCALE };
 enum { CELSIUS, FAHRENHEIT };
-enum { INVALID_VALUE = 0, TINY, SMALL, MEDIUM, LARGE, GIANT };
+enum { INVALID_VALUE = 0, TINY, SMALL, MEDIUM, BIG, LARGE, GIANT, SUPER_GIANT };
 enum { ICON, STATION_NAME };
 enum { MB, INCH, MM };
 enum { WEATHER_COM, RP5_RU, MAX_WEATHER_SOURCE_NUMBER };
